LifecycleState

Enum LifecycleState 

#[repr(u8)]
pub enum LifecycleState { Unconfigured = 1, Inactive = 2, Active = 3, Finalized = 4, ErrorProcessing = 5, }
Lifecycle state (REP-2002)

A lifecycle node is always in exactly one of these states.

Variants



Unconfigured = 1

Initial state after construction. Node is not yet configured.



Inactive = 2

Node is configured but not processing data.



Active = 3

Node is fully operational and processing data.



Finalized = 4

Terminal state. Node cannot be reused.



ErrorProcessing = 5

Error occurred during a transition. Must recover or shut down.

Implementations

Source

impl LifecycleState

pub const fn is_terminal(&self) -> bool

Returns true if this is a terminal state (Finalized).

pub const fn is_primary(&self) -> bool

Returns true if this is a primary state (not a transition state).

Primary states are: Unconfigured, Inactive, Active, Finalized. ErrorProcessing is the only non-primary state.

pub const fn from_u8(value: u8) -> Option<Self>

Try to convert from a u8 value.