pub trait Serialize {
// Required method
fn serialize(&self, writer: &mut CdrWriter<'_>) -> Result<(), SerError>;
}Expand description
Trait for types that can be serialized to CDR format
pub trait Serialize {
// Required method
fn serialize(&self, writer: &mut CdrWriter<'_>) -> Result<(), SerError>;
}Trait for types that can be serialized to CDR format