NanoRosError

Struct NanoRosError 

pub struct NanoRosError { /* private fields */ }
Main error type for nros operations

This error type provides comprehensive coverage of all failure modes in nros, with optional context information (topic name, service name, etc.) when available.

Error Categories

  • Serialization: CDR encoding/decoding failures
  • Transport: Network and communication failures
  • Node/Context: Node creation and management failures
  • Publisher/Subscriber: Pub/sub failures
  • Service/Client: Service call failures
  • Action: Action server/client failures
  • Timer: Timer management failures
  • Parameter: Parameter declaration/access failures

Example

use nros_core::NanoRosError;

let err = NanoRosError::timeout();
assert!(err.is_timeout());
assert!(!err.is_take_failed());

// Errors with context
let err = NanoRosError::topic_name_invalid("/invalid topic!");
assert!(err.context().is_some());

Implementations

Source

impl NanoRosError

pub const fn new(code: RclReturnCode) -> Self

Create a new error with the given code

pub const fn with_context(code: RclReturnCode, context: ErrorContext) -> Self

Create a new error with context

pub const fn timeout() -> Self

Create a timeout error

pub const fn invalid_argument() -> Self

Create an invalid argument error

pub const fn unsupported() -> Self

Create an unsupported operation error

pub const fn bad_alloc() -> Self

Create an allocation failure error

pub const fn error() -> Self

Create a generic error

pub const fn node_invalid() -> Self

Create an invalid node error

pub const fn node_invalid_name(name: &'static str) -> Self

Create an invalid node name error with context

pub const fn node_invalid_namespace(namespace: &'static str) -> Self

Create an invalid node namespace error with context

pub const fn topic_name_invalid(topic: &'static str) -> Self

Create an invalid topic name error with context

pub const fn publisher_invalid() -> Self

Create a publisher invalid error

pub const fn subscription_invalid() -> Self

Create a subscription invalid error

pub const fn subscription_take_failed() -> Self

Create a subscription take failed error

pub const fn service_name_invalid(service: &'static str) -> Self

Create an invalid service name error with context

pub const fn service_invalid() -> Self

Create a service invalid error

pub const fn service_take_failed() -> Self

Create a service take failed error

pub const fn client_invalid() -> Self

Create a client invalid error

pub const fn client_take_failed() -> Self

Create a client take failed error

pub const fn timer_invalid() -> Self

Create a timer invalid error

pub const fn timer_canceled() -> Self

Create a timer canceled error

pub const fn action_goal_rejected() -> Self

Create an action goal rejected error

pub const fn action_client_invalid() -> Self

Create an action client invalid error

pub const fn action_server_invalid() -> Self

Create an action server invalid error

pub const fn action_goal_handle_invalid() -> Self

Create an action goal handle invalid error

pub const fn already_init() -> Self

Create an already initialized error

pub const fn not_init() -> Self

Create a not initialized error

pub const fn already_shutdown() -> Self

Create an already shutdown error

pub fn serialization(err: SerError) -> Self

Create a serialization error

pub fn deserialization(err: DeserError) -> Self

Create a deserialization error

pub const fn code(&self) -> RclReturnCode

Returns the error code

pub const fn context(&self) -> Option<&ErrorContext>

Returns the error context, if any

pub const fn nested(&self) -> Option<&NestedError>

Returns the nested error, if any

pub const fn is_timeout(&self) -> bool

Returns true if this error was due to a timeout

pub const fn is_take_failed(&self) -> bool

Returns true if this error was because a take operation failed (subscription, service, client, or action take failed)

pub const fn is_action_error(&self) -> bool

Returns true if this is an action-related error

pub const fn is_serialization_error(&self) -> bool

Returns true if this is a serialization or deserialization error